@@ -31,10 +31,10 @@ def get_plot():
 plot = get_plot()
 
 pn.template.FastListTemplate(
-    site="Awesome Panel",
+    site="Awesome Panel Sharing",
+    site_url="https://awesome-panel.org/sharing",
+    favicon="https://raw.githubusercontent.com/MarcSkovMadsen/awesome-panel-assets/320297ccb92773da099f6b97d267cc0433b67c23/favicon/ap-1f77b4.ico",
     title="Cross Filtering",
     header_background=accent_color,
     main=[plot],
-    site_url="https://awesome-panel.org",
-    favicon="https://raw.githubusercontent.com/MarcSkovMadsen/awesome-panel-assets/320297ccb92773da099f6b97d267cc0433b67c23/favicon/ap-1f77b4.ico",
-).servable()
+).servable()
\ No newline at end of file
