@@ -29,11 +29,13 @@ def stream():
 periodic_callback = pn.state.add_periodic_callback(stream, PERIOD)
 
 pn.template.FastListTemplate(
-    site="Awesome Panel",
+    site="Awesome Panel Sharing",
+    site_url="https://awesome-panel.org/sharing",
+    favicon="https://raw.githubusercontent.com/MarcSkovMadsen/awesome-panel-assets/320297ccb92773da099f6b97d267cc0433b67c23/favicon/ap-1f77b4.ico",
     title="Streaming Indicators",
     main=[
         layout,
     ],
-    site_url="https://awesome-panel.org",
-    favicon="https://raw.githubusercontent.com/MarcSkovMadsen/awesome-panel-assets/320297ccb92773da099f6b97d267cc0433b67c23/favicon/ap-1f77b4.ico",
 ).servable()
+
+    
